@@ -20,7 +20,7 @@ import abc
 
 from pymatgen.serializers.json_coders import MSONable
 from pymatgen.core.structure import Structure
-from pymatgen.core.structure_modifier import StructureEditor
+from pymatgen.core.structure_modifier import StructureEditor, SupercellMaker
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.composition import Composition
 from pymatgen.optimization.linear_assignment import LinearAssignment
@@ -255,7 +255,8 @@ class StructureMatcher(MSONable):
     """
 
     def __init__(self, ltol=0.2, stol=0.3, angle_tol=5, primitive_cell=True,
-                 scale=True, comparator=SpeciesComparator()):
+                 scale=True, attempt_supercell=False,
+                 comparator=SpeciesComparator()):
         """
         Args:
             ltol:
@@ -263,7 +264,7 @@ class StructureMatcher(MSONable):
             stol:
                 Site tolerance. Defined as the fraction of the
                 average free length per atom := ( V / Nsites ) ** (1/3)
-                Default is 0.3
+                Default is 0.3.
             angle_tol:
                 Angle tolerance in degrees. Default is 5 degrees.
             primitive_cell:
@@ -272,6 +273,11 @@ class StructureMatcher(MSONable):
             scale:
                 Input structures are scaled to equivalent volume if true;
                 For exact matching, set to False.
+            attempt_supercell:
+                If set to True and number of sites in cells differ
+                after a primitive cell reduction (divisible by an integer)
+                attempts to generate a supercell transformation of the
+                smaller cell which is equivalent to the larger structure.
             comparator:
                 A comparator object implementing an equals method that declares
                 declaring equivalency of sites. Default is
@@ -292,12 +298,14 @@ class StructureMatcher(MSONable):
         self._comparator = comparator
         self._primitive_cell = primitive_cell
         self._scale = scale
+        self._supercell = attempt_supercell
 
     def _get_lattices(self, s1, s2, vol_tol):
         s1_lengths, s1_angles = s1.lattice.lengths_and_angles
         all_nn = get_points_in_sphere_pbc(
             s2.lattice, [[0, 0, 0]], [0, 0, 0],
             (1 + self.ltol) * max(s1_lengths))[:, [0, 1]]
+
         nv = []
         for l in s1_lengths:
             nvi = all_nn[np.where((all_nn[:, 1] < (1 + self.ltol) * l)
@@ -307,8 +315,7 @@ class StructureMatcher(MSONable):
             nvi = [np.array(site) for site in nvi]
             nvi = np.dot(nvi, s2.lattice.matrix)
             nv.append(nvi)
-
-        #The vectors are broadcast into a 5-D array containing
+            #The vectors are broadcast into a 5-D array containing
         #all permutations of the entries in nv[0], nv[1], nv[2]
         #produces the same result as three nested loops over the
         #same variables and calculating determinants individually
@@ -326,27 +333,27 @@ class StructureMatcher(MSONable):
         valid = np.where(abs(vol) >= vol_tol)
         if not len(valid[0]):
             return
-        #loop over valid lattices to compute the angles for each
+            #loop over valid lattices to compute the angles for each
         lengths = np.sum(bfl[valid] ** 2, axis=2) ** 0.5
         angles = np.zeros((len(bfl[valid]), 3), float)
         for i in xrange(3):
             j = (i + 1) % 3
             k = (i + 2) % 3
             angles[:, i] = \
-                np.sum(bfl[valid][:, j, :] * bfl[valid][:, k, :], 1)\
+                np.sum(bfl[valid][:, j, :] * bfl[valid][:, k, :], 1) \
                 / (lengths[:, j] * lengths[:, k])
         angles = np.arccos(angles) * 180. / np.pi
         #Check angles are within tolerance
         valid_angles = np.where(np.all(np.abs(angles - s1_angles) <
                                        self.angle_tol, axis=1))
-        if not len(valid_angles[0]):
+        if len(valid_angles[0]) == 0:
             return
-        #yield valid lattices
+            #yield valid lattices
         for lat in bfl[valid][valid_angles]:
             nl = Lattice(lat)
             yield nl
 
-    def _cmp_struct(self, s1, s2, frac_tol):
+    def _cmp_fractional_struct(self, s1, s2, frac_tol):
         #compares the fractional coordinates
         for s1_coords, s2_coords in zip(s1, s2):
             dist = s1_coords[:, None] - s2_coords[None, :]
@@ -372,7 +379,7 @@ class StructureMatcher(MSONable):
         4) return rms distance normalized by (V/Natom) ^ 1/3
             and the maximum distance found
         """
-        nsites = sum([len(i) for i in s1])
+        nsites = sum(map(len, s1))
 
         avg_params = (np.array(l1.lengths_and_angles) +
                       np.array(l2.lengths_and_angles)) / 2
@@ -383,19 +390,20 @@ class StructureMatcher(MSONable):
         vec_matrix = np.zeros([nsites, nsites, 3])
         i = 0
         for s1_coords, s2_coords in zip(s1, s2):
+            j = len(s1_coords)
             vecs = pbc_shortest_vectors(avg_lattice, s1_coords, s2_coords)
             distances = (np.sum(vecs ** 2, axis=-1)) ** 0.5
-            dist[i: i + len(s1_coords), i: i + len(s1_coords)] = distances
-            vec_matrix[i: i + len(s1_coords), i: i + len(s1_coords)] = vecs
-            i += len(s1_coords)
+            dist[i: i + j, i: i + j] = distances
+            vec_matrix[i: i + j, i: i + j] = vecs
+            i += j
         lin = LinearAssignment(dist)
         inds = np.arange(nsites)
 
         shortest_vecs = vec_matrix[inds, lin.solution, :]
-        shortest_vec_square = np.sum((shortest_vecs -
-                                      np.average(shortest_vecs, axis=0)) ** 2,
-                                     -1)
-        norm_length = (avg_lattice.volume / nsites) ** (1.0 / 3)
+        shortest_vec_square = np.sum(
+            (shortest_vecs - np.average(shortest_vecs, axis=0)) ** 2, -1)
+
+        norm_length = (avg_lattice.volume / nsites) ** (1 / 3)
 
         rms = np.average(shortest_vec_square) ** 0.5 / norm_length
 
@@ -403,6 +411,117 @@ class StructureMatcher(MSONable):
 
         return rms, max_dist
 
+    def _supercell_fit(self, struct1, struct2, break_on_match):
+        """
+        Calculate RMS displacement between two structures
+        where one is a potential supercell of the other
+
+        Args:
+            struct1:
+                1st structure
+            struct2:
+                2nd structure
+            break_on_match:
+                True or False. Will break if the maximum
+                    distance found is less than the
+                    provided stol
+
+        Returns:
+            rms displacement normalized by (Vol / nsites) ** (1/3) and
+            maximum distance found between two paired sites
+        """
+
+        stored_rms = None
+
+        #reset struct1 to supercell
+        if struct2.num_sites > struct1.num_sites:
+            [struct2, struct1] = [struct1, struct2]
+
+        #number of formula units
+        fu = struct1.num_sites / struct2.num_sites
+
+        struct1 = struct1.get_reduced_structure(reduction_algo="niggli")
+        struct2 = struct2.get_reduced_structure(reduction_algo="niggli")
+
+        nl1 = struct1.lattice
+        nl2 = struct2.lattice
+
+        #Volume to determine invalid lattices
+        vol_tol = fu * nl2.volume / 2
+
+        #fractional tolerance of atomic positions (2x for initial fitting)
+        frac_tol = np.array([self.stol / ((1 - self.ltol) * np.pi) * i
+                             for i in struct1.lattice.reciprocal_lattice.abc])
+        frac_tol *= ((nl1.volume + fu * nl2.volume) / (2 * struct1.num_sites)) \
+            ** (1 / 3)
+
+        #generate structure coordinate lists
+        species_list = []
+        s1 = []
+        for site in struct1:
+            found = False
+            for i, species in enumerate(species_list):
+                if self._comparator.are_equal(site.species_and_occu,
+                                              species):
+                    found = True
+                    s1[i].append(site.frac_coords)
+                    break
+            if not found:
+                s1.append([site.frac_coords])
+                species_list.append(site.species_and_occu)
+
+        zipped = sorted(zip(s1, species_list), key=lambda x: len(x[0]))
+
+        s1 = [x[0] for x in zipped]
+        species_list = [x[1] for x in zipped]
+
+        #translate s1
+        s1_translation = s1[0][0]
+        for i in range(len(species_list)):
+            s1[i] = np.mod(s1[i] - s1_translation, 1)
+
+        #do permutations of vectors, check for equality
+        for nl in self._get_lattices(struct1, struct2, vol_tol):
+
+            s2_cart = [[] for i in s1]
+
+            scale_matrix = np.round(np.dot(nl.matrix, nl2.inv_matrix))
+
+            scm = SupercellMaker(struct2, scale_matrix.astype('int'))
+
+            for site in scm.modified_structure.sites:
+                found = False
+                for i, species in enumerate(species_list):
+                    if self._comparator.are_equal(site.species_and_occu,
+                                                  species):
+                        found = True
+                        s2_cart[i].append(site.coords)
+                        break
+                        #if no site match found return None
+                if not found:
+                    return None
+
+            #check that sizes of the site groups are identical
+            for f1, c2 in zip(s1, s2_cart):
+                if len(f1) != len(c2):
+                    return None
+
+            s2 = [nl.get_fractional_coords(c) for c in s2_cart]
+            for coord in s2[0]:
+                t_s2 = [np.mod(coords - coord, 1) for coords in s2]
+                if self._cmp_fractional_struct(s1, t_s2, frac_tol):
+                    rms, max_dist = self._cmp_cartesian_struct(s1, t_s2, nl,
+                                                               nl1)
+                    if break_on_match and max_dist < self.stol:
+                        return max_dist
+                    elif stored_rms is None or rms < stored_rms[0]:
+                        stored_rms = rms, max_dist
+
+        if break_on_match:
+            return None
+        else:
+            return stored_rms
+
     def fit(self, struct1, struct2):
         """
         Fit two structures.
@@ -421,7 +540,6 @@ class StructureMatcher(MSONable):
 
         if fit_dist is None:
             return False
-
         else:
             return fit_dist <= self.stol
 
@@ -437,8 +555,10 @@ class StructureMatcher(MSONable):
 
         Returns:
             rms displacement normalized by (Vol / nsites) ** (1/3)
-            and maximum distance between paired sites
+            and maximum distance between paired sites. If no matching
+            lattice is found None is returned.
         """
+
         return self._calc_rms(struct1, struct2, break_on_match=False)
 
     def _calc_rms(self, struct1, struct2, break_on_match):
@@ -461,7 +581,10 @@ class StructureMatcher(MSONable):
         """
         stol = self.stol
         comparator = self._comparator
-        if comparator.get_structure_hash(struct1) !=\
+        #initial stored rms
+        stored_rms = None
+
+        if comparator.get_structure_hash(struct1) != \
                 comparator.get_structure_hash(struct2):
             return None
 
@@ -472,9 +595,13 @@ class StructureMatcher(MSONable):
 
         # Same number of sites
         if struct1.num_sites != struct2.num_sites:
-            return None
-        #initial stored rms
-        stored_rms = [np.Inf, np.Inf]
+            #if mismatch try to fit a supercell or return None
+            if self._supercell and not (
+                    (struct1.num_sites % struct2.num_sites)
+                    and (struct2.num_sites % struct1.num_sites)):
+                return self._supercell_fit(struct1, struct2, break_on_match)
+            else:
+                return None
 
         # Get niggli reduced cells. Though technically not necessary, this
         # minimizes cell lengths and speeds up the matching of skewed
@@ -501,10 +628,12 @@ class StructureMatcher(MSONable):
         vol_tol = nl2.volume / 2
 
         #fractional tolerance of atomic positions (2x for initial fitting)
-        frac_tol = (1 / (1 - self.ltol)) * \
-            np.array([stol / i for i in struct1.lattice.abc]) * \
-                   ((nl1.volume + nl2.volume) /
-                    (2 * struct1.num_sites)) ** (1.0 / 3)
+        frac_tol = \
+            np.array([stol / ((1 - self.ltol) * np.pi) * i for
+                      i in struct1.lattice.reciprocal_lattice.abc]) * \
+            ((nl1.volume + nl2.volume) /
+             (2 * struct1.num_sites)) ** (1.0 / 3)
+
         #generate structure coordinate lists
         species_list = []
         s1 = []
@@ -532,7 +661,7 @@ class StructureMatcher(MSONable):
                     found = True
                     s2_cart[i].append(site.coords)
                     break
-            #if no site match found return None
+                    #if no site match found return None
             if not found:
                 return None
 
@@ -545,18 +674,18 @@ class StructureMatcher(MSONable):
         s1_translation = s1[0][0]
         for i in range(len(species_list)):
             s1[i] = np.mod(s1[i] - s1_translation, 1)
-        #do permutations of vectors, check for equality
+            #do permutations of vectors, check for equality
         for nl in self._get_lattices(struct1, struct2, vol_tol):
             s2 = [nl.get_fractional_coords(c) for c in s2_cart]
             for coord in s2[0]:
                 t_s2 = [np.mod(coords - coord, 1) for coords in s2]
-                if self._cmp_struct(s1, t_s2, frac_tol):
+                if self._cmp_fractional_struct(s1, t_s2, frac_tol):
                     rms, max_dist = self._cmp_cartesian_struct(s1, t_s2, nl,
                                                                nl1)
                     if break_on_match and max_dist < stol:
                         return max_dist
-                    elif rms < stored_rms[0]:
-                        stored_rms = [rms, max_dist]
+                    elif stored_rms is None or rms < stored_rms[0]:
+                        stored_rms = rms, max_dist
 
         if break_on_match:
             return None
@@ -577,7 +706,7 @@ class StructureMatcher(MSONable):
         inds = [-1] * len(s_list)
         for j in range(len(s_list)):
             for i in range(len(group_list)):
-                if len(np.where(s_list[j] in group_list[i])[0]):
+                if s_list[j] in group_list[i]:
                     inds[j] = i
                     break
         return inds
@@ -632,6 +761,50 @@ class StructureMatcher(MSONable):
             primitive_cell=d["primitive_cell"], scale=d["scale"],
             comparator=AbstractComparator.from_dict(d["comparator"]))
 
+    def get_minimax_rms_anonymous(self, struct1, struct2):
+        """
+        Performs an anonymous fitting, which allows distinct species in one
+        structure to map to another. E.g., to compare if the Li2O and Na2O
+        structures are similar.
+
+        Args:
+            struct1:
+                1st structure
+            struct2:
+                2nd structure
+
+        Returns:
+            (minimax_rms, min_mapping)
+            min_rms is the minimum of the max rms calculated, and min_mapping
+            is the corresponding minimal species mapping that would map
+            struct1 to struct2. (None, None) is returned if the minimax_rms
+            exceeds the threshold.
+        """
+        sp1 = list(set(struct1.species_and_occu))
+        sp2 = list(set(struct2.species_and_occu))
+
+        if len(sp1) != len(sp2):
+            return None
+
+        latt1 = struct1.lattice
+        fcoords1 = struct1.frac_coords
+        min_rms = float("inf")
+        min_mapping = None
+        for perm in itertools.permutations(sp2):
+            sp_mapping = dict(zip(sp1, perm))
+            mapped_sp = [sp_mapping[site.species_and_occu] for site in struct1]
+            transformed_structure = Structure(latt1, mapped_sp, fcoords1)
+            rms = self.get_rms_dist(transformed_structure, struct2)
+            if rms is not None:
+                if min_rms > rms[1]:
+                    min_rms = rms[1]
+                    min_mapping = {k: v for k, v in sp_mapping.items()
+                                   if k != v}
+        if min_mapping is None:
+            return None, None
+        else:
+            return min_rms, min_mapping
+
     def fit_anonymous(self, struct1, struct2):
         """
         Performs an anonymous fitting, which allows distinct species in one
@@ -655,23 +828,8 @@ class StructureMatcher(MSONable):
             occupancy dicts. This complicated return for is necessary because
             species and occupancy dicts are non-hashable.
         """
-        sp1 = list(set(struct1.species_and_occu))
-        sp2 = list(set(struct2.species_and_occu))
-
-        if len(sp1) != len(sp2):
+        min_rms, min_mapping = self.get_minimax_rms_anonymous(struct1, struct2)
+        if min_rms is None or min_rms > self.stol:
             return None
-
-        for perm in itertools.permutations(sp2):
-            perm = list(perm)
-            mapped_sp = []
-            for site in struct1:
-                ind = sp1.index(site.species_and_occu)
-                mapped_sp.append(perm[ind])
-
-            transformed_structure = Structure(struct1.lattice, mapped_sp,
-                                              struct1.frac_coords)
-            if self.fit(transformed_structure, struct2):
-                return {sp1[i]: perm[i] for i in xrange(len(sp1))
-                        if sp1[i] != perm[i]}
-
-        return None
\ No newline at end of file
+        else:
+            return min_mapping
\ No newline at end of file
