@@ -23,6 +23,8 @@ try:
     import pybel as pb
     babel_loaded = True
 except ImportError:
+    pb = None
+    ob = None
     babel_loaded = False
 
 
@@ -38,7 +40,7 @@ class BabelMolAdaptor(object):
 
         Args:
             mol:
-                pymatgen"s Molecule or OpenBabel Molecule
+                pymatgen"s Molecule or OpenBabel OBMol
         """
         if isinstance(mol, Molecule):
             if not mol.is_ordered:
@@ -90,11 +92,11 @@ class BabelMolAdaptor(object):
     @staticmethod
     def from_file(filename, file_format="xyz"):
         """
-        Uses OpenBabel to read a molecule from all supported formats.
+        Uses OpenBabel to read a molecule from a file in all supported formats.
 
         Args:
             filename:
-                Filename of file to output
+                Filename of input file
             file_format:
                 String specifying any OpenBabel supported formats.
 
@@ -103,3 +105,21 @@ class BabelMolAdaptor(object):
         """
         mols = list(pb.readfile(file_format, filename))
         return BabelMolAdaptor(mols[0].OBMol)
+
+    @staticmethod
+    def from_string(string_data, file_format="xyz"):
+        """
+        Uses OpenBabel to read a molecule from a string in all supported
+        formats.
+
+        Args:
+            string_data:
+                String containing molecule data.
+            file_format:
+                String specifying any OpenBabel supported formats.
+
+        Returns:
+            BabelMolAdaptor object
+        """
+        mols = pb.readstring(file_format, string_data)
+        return BabelMolAdaptor(mols.OBMol)
