@@ -138,7 +138,8 @@ class Poscar(MSONable):
 
     def __setattr__(self, name, value):
         if name in ("selective_dynamics", "velocities"):
-            if value:
+            if value is not None and len(value) > 0:
+                value = list(value)
                 dim = np.array(value).shape
                 if dim[1] != 3 or dim[0] != len(self.structure):
                     raise ValueError(name + " array must be same length as" +
@@ -228,8 +229,10 @@ class Poscar(MSONable):
             Poscar object.
         """
 
-        chunks = re.split("^\s*$", data.strip(), flags=re.MULTILINE)
-
+        chunks = re.split("^\s*$", data.rstrip(), flags=re.MULTILINE)
+        if chunks[0] == "":
+            chunks.pop(0)
+            chunks[0] = "\n" + chunks[0]
         #Parse positions
         lines = tuple(clean_lines(chunks[0].split("\n"), False))
         comment = lines[0]
@@ -366,7 +369,7 @@ class Poscar(MSONable):
         for (i, site) in enumerate(self.structure):
             coords = site.frac_coords if direct else site.coords
             line = " ".join([format_str.format(c) for c in coords])
-            if self.selective_dynamics:
+            if self.selective_dynamics is not None:
                 sd = ["T" if j else "F" for j in self.selective_dynamics[i]]
                 line += " %s %s %s" % (sd[0], sd[1], sd[2])
             line += " " + site.species_string
@@ -728,7 +731,7 @@ class Kpoints(MSONable):
                 given in Cartesian or Reciprocal coordinates.
             labels:
                 In line-mode, this should provide a list of labels for each
-                kpt.
+                kpt. It is optional in explicit kpoint mode as comments for k-points.
             tet_number:
                 For explicit kpoints, specifies the number of tetrahedrons for
                 the tetrahedron method.
@@ -1000,7 +1003,11 @@ class Kpoints(MSONable):
             if style == "l":
                 lines[-1] += " ! " + self.labels[i]
             elif self.num_kpts > 0:
-                lines[-1] += " %f" % (self.kpts_weights[i])
+                if self.labels is not None:
+                    lines[-1] += " %f %s" % (self.kpts_weights[i], self.labels[i])
+                else:
+                    lines[-1] += " %f" % (self.kpts_weights[i])
+
 
         #Print tetrahedorn parameters if the number of tetrahedrons > 0
         if style not in "lagm" and self.tet_number > 0:
