@@ -14,6 +14,7 @@ https://www.materialsproject.org/profile.
 from __future__ import division
 
 __author__ = "Shyue Ping Ong, Shreyas Cholia"
+__credits__ = "Anubhav Jain"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
@@ -26,6 +27,7 @@ import json
 import warnings
 
 from pymatgen import Composition, PMGJSONDecoder
+from pymatgen.entries.computed_entries import ComputedStructureEntry
 from pymatgen.entries.compatibility import MaterialsProjectCompatibility
 from pymatgen.entries.exp_entries import ExpEntry
 from pymatgen.io.vaspio_set import DictVaspInputSet
@@ -113,7 +115,7 @@ class MPRester(object):
                 "exp".
             prop:
                 Property to be obtained. Should be one of the
-                MPRestAdaptor.supported_properties. Leave as empty string for a
+                MPRester.supported_properties. Leave as empty string for a
                 general list of useful properties.
         """
         if prop:
@@ -160,10 +162,11 @@ class MPRester(object):
         data = self.get_data(chemsys_formula_id, prop=prop)
         return [d[prop] for d in data]
 
-    def get_entries(self, chemsys_formula_id, compatible_only=True):
+    def get_entries(self, chemsys_formula_id, compatible_only=True,
+                    inc_structure=None):
         """
-        Get a list of ComputedEntries corresponding to  a chemical system,
-        formula, or materials_id.
+        Get a list of ComputedEntries or ComputedStructureEntries corresponding
+        to a chemical system, formula, or materials_id.
 
         Args:
             chemsys_formula_id:
@@ -175,14 +178,31 @@ class MPRester(object):
                 MaterialsProjectCompatibility class, which performs adjustments
                 to allow mixing of GGA and GGA+U calculations for more accurate
                 phase diagrams and reaction energies.
+            inc_structure:
+                If None, entries returned are ComputedEntries. If
+                inc_structure="final", ComputedStructureEntries with final
+                structures are returned. Otherwise, ComputedStructureEntries
+                with initial structures are returned.
 
         Returns:
-            List of ComputedEntry objects.
+            List of ComputedEntry or ComputedStructureEntry objects.
         """
         data = self.get_data(chemsys_formula_id, prop="entry")
         entries = [d["entry"] for d in data]
+
+        def make_struct_entry(entry):
+            s = self.get_structure_by_material_id(entry.entry_id,
+                                                  inc_structure == "final")
+            return ComputedStructureEntry(s, entry.energy,
+                                          entry.correction, entry.parameters,
+                                          entry.data, entry.entry_id)
+
+        if inc_structure:
+            entries = map(make_struct_entry, entries)
+
         if compatible_only:
             entries = MaterialsProjectCompatibility().process_entries(entries)
+
         return entries
 
     def get_structure_by_material_id(self, material_id, final=True):
@@ -219,7 +239,7 @@ class MPRester(object):
 
     def get_dos_by_material_id(self, material_id):
         """
-        Get a ComputedEntry corresponding to a material_id.
+        Get a Dos corresponding to a material_id.
 
         Args:
             material_id:
@@ -233,14 +253,14 @@ class MPRester(object):
 
     def get_bandstructure_by_material_id(self, material_id):
         """
-        Get a ComputedEntry corresponding to a material_id.
+        Get a BandStructure corresponding to a material_id.
 
         Args:
             material_id:
                 Materials Project material_id (an int).
 
         Returns:
-            A Bandstructure object.
+            A BandStructure object.
         """
         data = self.get_data(material_id, prop="bandstructure")
         return data[0]["bandstructure"]
