@@ -69,7 +69,16 @@ class AbstractTransformation(MSONable):
         returned as a ranked list.
         """
         return False
-
+    
+    @property
+    def use_multiprocessing(self):
+        """
+        Indicates whether the transformation can be applied by a 
+        subprocessing pool. This should be overridden to return True for 
+        transformations that the transmuter can parallelize.
+        """
+        return False
+    
     @staticmethod
     def from_dict(d):
         for trans_modules in ['standard_transformations',
