@@ -77,19 +77,16 @@ def get_linear_interpolated_value(x_values, y_values, x):
     Returns:
         Value at x.
     """
-    val_dict = dict(zip(x_values, y_values))
-    if x < min(x_values) or x > max(x_values):
+    a = np.array(sorted(zip(x_values, y_values), key=lambda d: d[0]))
+
+    ind = np.where(a[:, 0] >= x)[0]
+
+    if len(ind) == 0 or ind[0] == 0:
         raise ValueError("x is out of range of provided x_values")
 
-    for val in sorted(x_values):
-        if val < x:
-            x1 = val
-        else:
-            x2 = val
-            break
-
-    y1 = val_dict[x1]
-    y2 = val_dict[x2]
+    i = ind[0]
+    x1, x2 = a[i - 1][0], a[i][0]
+    y1, y2 = a[i - 1][1], a[i][1]
 
     return y1 + (y2 - y1) / (x2 - x1) * (x - x1)
 
@@ -170,6 +167,7 @@ def pbc_all_distances(lattice, fcoords1, fcoords2):
 
     return distances
 
+
 def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
     """
     Returns the shortest vectors between two lists of coordinates taking into
@@ -217,6 +215,7 @@ def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
     a, b = np.indices([len(fcoords1), len(fcoords1)])
     return vectors[a, b, np.argmin(d_2, axis=2)]
 
+
 def find_in_coord_list_pbc(fcoord_list, fcoord, atol=1e-8):
     """
     Get the indices of all points in a fractional coord list that are
